==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/kobo.md <==
## Kobo E-Reader Dictionary

### General Information

| Attribute       | Value                                                      |
| --------------- | ---------------------------------------------------------- |
| Name            | Kobo                                                       |
| snake_case_name | kobo                                                       |
| Description     | Kobo E-Reader Dictionary                                   |
| Extensions      | `.kobo`                                                    |
| Read support    | No                                                         |
| Write support   | Yes                                                        |
| Single-file     | No                                                         |
| Kind            | 📦 package                                                  |
| Sort-on-write   | never                                                      |
| Sort key        | (`headword_lower`)                                         |
| Wiki            | [Kobo eReader](https://en.wikipedia.org/wiki/Kobo_eReader) |
| Website         | [www.kobo.com](https://www.kobo.com)                       |


### Dependencies for writing

PyPI Links: [marisa-trie](https://pypi.org/project/marisa-trie)

To install, run
```sh
pip3 install marisa-trie
```

### Dictionary Applications/Tools

| Name & Website                       | License     | Platforms    |
| ------------------------------------ | ----------- | ------------ |
| [Kobo eReader](https://www.kobo.com) | Proprietary | Kobo eReader |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/kobo.md <==
## Kobo E-Reader Dictionary

### General Information

| Attribute       | Value                                                      |
| --------------- | ---------------------------------------------------------- |
| Name            | Kobo                                                       |
| snake_case_name | kobo                                                       |
| Description     | Kobo E-Reader Dictionary                                   |
| Extensions      | `.kobo`                                                    |
| Read support    | No                                                         |
| Write support   | Yes                                                        |
| Single-file     | No                                                         |
| Kind            | 📦 package                                                  |
| Sort-on-write   | Never                                                      |
| Sort key        | (`headword_lower`)                                         |
| Wiki            | [Kobo eReader](https://en.wikipedia.org/wiki/Kobo_eReader) |
| Website         | [www.kobo.com](https://www.kobo.com)                       |

### Dependencies for writing

PyPI Links: [marisa-trie](https://pypi.org/project/marisa-trie)

To install, run

```sh
pip3 install marisa-trie
```

### Dictionary Applications/Tools

| Name & Website                       | Source code | License     | Platforms    | Language |
| ------------------------------------ | ----------- | ----------- | ------------ | -------- |
| [Kobo eReader](https://www.kobo.com) | ―           | Proprietary | Kobo eReader |          |
